@@ -47,6 +47,7 @@
 #include "CodeGenHelper.hh"
 #include <limits.h>
 #include "ttcn3/profiler.h"
+#include "ttcn3/Ttcnstuff.hh"
 
 reffer::reffer(const char*) {}
 
@@ -1320,7 +1321,7 @@ namespace Common {
     control_ns_prefix(p_mt == MOD_ASN ? mcopystr("asn1") : NULL),
     // only ASN.1 modules have default control namespace (X.693 amd1, 16.9)
     used_namespaces(), type_conv_v(), product_number(NULL),
-    suffix(0), release(UINT_MAX), patch(UINT_MAX), build(UINT_MAX), extra(NULL), version_type(UNKNOWN)
+    suffix(0), release(UINT_MAX), patch(UINT_MAX), build(UINT_MAX), extra(NULL), version_type(UNKNOWN_VERSION_TYPE)
   {
     if(!p_modid)
       FATAL_ERROR("NULL parameter: Common::Module::Module()");
@@ -2004,11 +2005,15 @@ namespace Common {
 
     Module *my_mod = my_scope->get_scope_mod_gen();
     if ((my_mod != p_scope->get_scope_mod_gen()) &&
-    !Asn::Assignments::is_spec_asss(my_mod)) {
-    // when the definition is referred from another module
-    // the reference shall be qualified with the namespace of my module
-    ret_val = my_mod->get_modid().get_name();
-    ret_val += "::";
+      !Asn::Assignments::is_spec_asss(my_mod)) {
+      // when the definition is referred from another module
+      // the reference shall be qualified with the namespace of my module
+      ret_val = my_mod->get_modid().get_name();
+      ret_val += "::";
+      if (my_scope->get_scope_class() != NULL) {
+        ret_val += my_scope->get_scope_class()->get_id()->get_name();
+        ret_val += "::";
+      }
     }
     if (p_prefix) ret_val += p_prefix;
     ret_val += get_genname();
