@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2020 Ericsson Telecom AB
+ * Copyright (c) 2000-2021 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -963,6 +963,10 @@ namespace Common {
     return false;
   }
 
+  bool ReferenceChain::is_error_reporting_on() const {
+    return report_error;
+  }
+
   void ReferenceChain::set_error_reporting(bool enable) {
     report_error = enable;
   }
