@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2020 Ericsson Telecom AB
+ * Copyright (c) 2000-2021 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -68,6 +68,7 @@ XerAttributes::XerAttributes()
 {
   //__asm("int3");
   //fprintf(stderr, "XER attributes(%p) new\n", (void*)this);
+  namespace_.global_variant = false;
 }
 
 void FreeNamespaceRestriction(NamespaceRestriction& nsr)
@@ -121,6 +122,7 @@ void XerAttributes::FreeNamespace(NamespaceSpecification &ns) {
   ns.uri = 0;
   Free(ns.prefix);
   ns.prefix = 0;
+  ns.global_variant = false;
 }
 
 void XerAttributes::FreeNameChange(XerAttributes::NameChange& n) {
@@ -324,7 +326,9 @@ other.print("other");
     }
   }
 
-  if (other.namespace_.uri != 0) {
+  if (other.namespace_.uri != 0 &&
+      // global namespace variants should no longer overwrite inherited namespace variants (issue #545)
+      (namespace_.uri == 0 || !other.namespace_.global_variant)) {
     switch (namespace_.keyword) {
     case NamespaceSpecification::NO_MANGLING:
     case NamespaceSpecification::CAPITALIZED:
