@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2020 Ericsson Telecom AB
+ * Copyright (c) 2000-2021 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -121,7 +121,7 @@ void ASN_NULL::decode_text(Text_Buf&)
 }
 
 void ASN_NULL::encode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
-                      TTCN_EncDec::coding_t p_coding, ...) const
+                      int p_coding, ...) const
 {
   va_list pvar;
   va_start(pvar, p_coding);
@@ -163,7 +163,7 @@ void ASN_NULL::encode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
 }
 
 void ASN_NULL::decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
-                      TTCN_EncDec::coding_t p_coding, ...)
+                      int p_coding, ...)
 {
   va_list pvar;
   va_start(pvar, p_coding);
