@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2020 Ericsson Telecom AB
+ * Copyright (c) 2000-2021 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -204,7 +204,7 @@ Module_Param* BOOLEAN::get_param(Module_Param_Name& /* param_name */) const
 #endif
 
 void BOOLEAN::encode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
-                     TTCN_EncDec::coding_t p_coding, ...) const
+                     int p_coding, ...) const
 {
   va_list pvar;
   va_start(pvar, p_coding);
@@ -264,7 +264,7 @@ void BOOLEAN::encode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
 }
 
 void BOOLEAN::decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
-                     TTCN_EncDec::coding_t p_coding, ...)
+                     int p_coding, ...)
 {
   va_list pvar;
   va_start(pvar, p_coding);
@@ -770,9 +770,13 @@ int BOOLEAN::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer& p_to
 {
   json_token_t token = JSON_TOKEN_NONE;
   size_t dec_len = 0;
-  if (p_td.json->default_value && 0 == p_tok.get_buffer_length()) {
+  if (p_td.json->default_value.type == JD_STANDARD && 0 == p_tok.get_buffer_length()) {
+    *this = *static_cast<const BOOLEAN*>(p_td.json->default_value.val);
+    return dec_len;
+  }
+  if (p_td.json->default_value.type == JD_LEGACY && 0 == p_tok.get_buffer_length()) {
     // No JSON data in the buffer -> use default value
-    if (strcmp(p_td.json->default_value, "true") == 0) {
+    if (strcmp(p_td.json->default_value.str, "true") == 0) {
       token = JSON_TOKEN_LITERAL_TRUE;
     } 
     else {
@@ -861,9 +865,26 @@ boolean operator==(boolean bool_value, const BOOLEAN& other_value)
 
 void BOOLEAN_template::clean_up()
 {
-  if (template_selection == VALUE_LIST ||
-      template_selection == COMPLEMENTED_LIST)
+  switch (template_selection) {
+  case VALUE_LIST:
+  case COMPLEMENTED_LIST:
+  case CONJUNCTION_MATCH:
     delete [] value_list.list_value;
+    break;
+  case IMPLICATION_MATCH:
+    delete implication_.precondition;
+    delete implication_.implied_template;
+    break;
+  case DYNAMIC_MATCH:
+    dyn_match->ref_count--;
+    if (dyn_match->ref_count == 0) {
+      delete dyn_match->ptr;
+      delete dyn_match;
+    }
+    break;
+  default:
+    break;
+  }
   template_selection = UNINITIALIZED_TEMPLATE;
 }
 
@@ -879,12 +900,21 @@ void BOOLEAN_template::copy_template(const BOOLEAN_template& other_value)
     break;
   case VALUE_LIST:
   case COMPLEMENTED_LIST:
+  case CONJUNCTION_MATCH:
     value_list.n_values = other_value.value_list.n_values;
     value_list.list_value = new BOOLEAN_template[value_list.n_values];
     for (unsigned int i = 0; i < value_list.n_values; i++)
       value_list.list_value[i].copy_template(
         other_value.value_list.list_value[i]);
     break;
+  case IMPLICATION_MATCH:
+    implication_.precondition = new BOOLEAN_template(*other_value.implication_.precondition);
+    implication_.implied_template = new BOOLEAN_template(*other_value.implication_.implied_template);
+    break;
+  case DYNAMIC_MATCH:
+    dyn_match = other_value.dyn_match;
+    dyn_match->ref_count++;
+    break;
   default:
     TTCN_error("Copying an uninitialized/unsupported boolean template.");
   }
@@ -936,6 +966,21 @@ BOOLEAN_template::BOOLEAN_template(const BOOLEAN_template& other_value)
   copy_template(other_value);
 }
 
+BOOLEAN_template::BOOLEAN_template(BOOLEAN_template* p_precondition, BOOLEAN_template* p_implied_template)
+: Base_Template(IMPLICATION_MATCH)
+{
+  implication_.precondition = p_precondition;
+  implication_.implied_template = p_implied_template;
+}
+
+BOOLEAN_template::BOOLEAN_template(Dynamic_Match_Interface<BOOLEAN>* p_dyn_match)
+: Base_Template(DYNAMIC_MATCH)
+{
+  dyn_match = new dynmatch_struct<BOOLEAN>;
+  dyn_match->ptr = p_dyn_match;
+  dyn_match->ref_count = 1;
+}
+
 BOOLEAN_template::~BOOLEAN_template()
 {
   clean_up();
@@ -1013,6 +1058,17 @@ boolean BOOLEAN_template::match(boolean other_value,
       if (value_list.list_value[i].match(other_value))
         return template_selection == VALUE_LIST;
     return template_selection == COMPLEMENTED_LIST;
+  case CONJUNCTION_MATCH:
+    for (unsigned int i = 0; i < value_list.n_values; i++) {
+      if (!value_list.list_value[i].match(other_value)) {
+        return FALSE;
+      }
+    }
+    return TRUE;
+  case IMPLICATION_MATCH:
+    return !implication_.precondition->match(other_value) || implication_.implied_template->match(other_value);
+  case DYNAMIC_MATCH:
+    return dyn_match->ptr->match(other_value);
   default:
     TTCN_error("Matching with an uninitialized/unsupported boolean template.");
   }
@@ -1037,7 +1093,8 @@ boolean BOOLEAN_template::valueof() const
 void BOOLEAN_template::set_type(template_sel template_type,
   unsigned int list_length)
 {
-  if (template_type != VALUE_LIST && template_type != COMPLEMENTED_LIST)
+  if (template_type != VALUE_LIST && template_type != COMPLEMENTED_LIST &&
+      template_type != CONJUNCTION_MATCH)
     TTCN_error("Setting an invalid list type for a boolean template.");
   clean_up();
   set_selection(template_type);
@@ -1048,7 +1105,8 @@ void BOOLEAN_template::set_type(template_sel template_type,
 BOOLEAN_template& BOOLEAN_template::list_item(unsigned int list_index)
 {
   if (template_selection != VALUE_LIST &&
-      template_selection != COMPLEMENTED_LIST)
+      template_selection != COMPLEMENTED_LIST &&
+      template_selection != CONJUNCTION_MATCH)
     TTCN_error("Accessing a list element of a non-list boolean template.");
   if (list_index >= value_list.n_values)
     TTCN_error("Index overflow in a boolean value list template.");
@@ -1064,6 +1122,11 @@ void BOOLEAN_template::log() const
   case COMPLEMENTED_LIST:
     TTCN_Logger::log_event_str("complement");
     // no break
+  case CONJUNCTION_MATCH:
+    if (template_selection == CONJUNCTION_MATCH) {
+      TTCN_Logger::log_event_str("conjunct");
+    }
+    // no break
   case VALUE_LIST:
     TTCN_Logger::log_char('(');
     for (unsigned int i = 0; i < value_list.n_values; i++) {
@@ -1072,6 +1135,14 @@ void BOOLEAN_template::log() const
     }
     TTCN_Logger::log_char(')');
     break;
+  case IMPLICATION_MATCH:
+    implication_.precondition->log();
+    TTCN_Logger::log_event_str(" implies ");
+    implication_.implied_template->log();
+    break;
+  case DYNAMIC_MATCH:
+    TTCN_Logger::log_event_str("@dynamic template");
+    break;
   default:
     log_generic();
     break;
@@ -1113,10 +1184,12 @@ void BOOLEAN_template::set_param(Module_Param& param) {
     *this = ANY_OR_OMIT;
     break;
   case Module_Param::MP_List_Template:
-  case Module_Param::MP_ComplementList_Template: {
+  case Module_Param::MP_ComplementList_Template:
+  case Module_Param::MP_ConjunctList_Template: {
     BOOLEAN_template temp;
     temp.set_type(mp->get_type() == Module_Param::MP_List_Template ?
-      VALUE_LIST : COMPLEMENTED_LIST, mp->get_size());
+      VALUE_LIST : (mp->get_type() == Module_Param::MP_ConjunctList_Template ?
+      CONJUNCTION_MATCH : COMPLEMENTED_LIST), mp->get_size());
     for (size_t i=0; i<mp->get_size(); i++) {
       temp.list_item(i).set_param(*mp->get_elem(i));
     }
@@ -1125,6 +1198,13 @@ void BOOLEAN_template::set_param(Module_Param& param) {
   case Module_Param::MP_Boolean:
     *this = mp->get_boolean();
     break;
+  case Module_Param::MP_Implication_Template: {
+    BOOLEAN_template* precondition = new BOOLEAN_template;
+    precondition->set_param(*mp->get_elem(0));
+    BOOLEAN_template* implied_template = new BOOLEAN_template;
+    implied_template->set_param(*mp->get_elem(1));
+    *this = BOOLEAN_template(precondition, implied_template);
+  } break;
   default:
     param.type_error("boolean template");
   }
@@ -1152,10 +1232,14 @@ Module_Param* BOOLEAN_template::get_param(Module_Param_Name& param_name) const
     mp = new Module_Param_Boolean(single_value);
     break;
   case VALUE_LIST:
-  case COMPLEMENTED_LIST: {
+  case COMPLEMENTED_LIST:
+  case CONJUNCTION_MATCH: {
     if (template_selection == VALUE_LIST) {
       mp = new Module_Param_List_Template();
     }
+    else if (template_selection == CONJUNCTION_MATCH) {
+      mp = new Module_Param_ConjunctList_Template();
+    }
     else {
       mp = new Module_Param_ComplementList_Template();
     }
@@ -1163,6 +1247,11 @@ Module_Param* BOOLEAN_template::get_param(Module_Param_Name& param_name) const
       mp->add_elem(value_list.list_value[i].get_param(param_name));
     }
     break; }
+  case IMPLICATION_MATCH:
+    mp = new Module_Param_Implication_Template();
+    mp->add_elem(implication_.precondition->get_param(param_name));
+    mp->add_elem(implication_.implied_template->get_param(param_name));
+    break;
   default:
     TTCN_error("Referencing an uninitialized/unsupported boolean template.");
     break;
@@ -1246,6 +1335,8 @@ boolean BOOLEAN_template::match_omit(boolean legacy /* = FALSE */) const
   case OMIT_VALUE:
   case ANY_OR_OMIT:
     return TRUE;
+  case IMPLICATION_MATCH:
+    return !implication_.precondition->match_omit() || implication_.implied_template->match_omit();
   case VALUE_LIST:
   case COMPLEMENTED_LIST:
     if (legacy) {
