@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2020 Ericsson Telecom AB
+ * Copyright (c) 2000-2021 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -810,6 +810,11 @@ void TTCN_Communication::send_version()
   text_buf.push_int(TRANSPORT_INET_STREAM);
   if (unix_stream_supported)
     text_buf.push_int(TRANSPORT_UNIX_STREAM);
+  if (local_addr_set) {
+    text_buf.push_string(hcnh.get_local_addr_str());
+  } else {
+    text_buf.push_string("");
+  }
   send_message(text_buf);
 }
 
