@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2020 Ericsson Telecom AB
+ * Copyright (c) 2000-2021 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -743,9 +743,10 @@ void TTCN_Buffer::put_b(size_t len, const unsigned char *s,
   }
 /*printf("len:%d\r\n",len);
 printf("align:%d\r\n",align);
-printf("coding bito:%s,byte:%s,field:%s\r\n",coding_par.bitorder==ORDER_MSB?"M":"L",
+printf("coding bito:%s,byte:%s,field:%s, hex: %s\r\n",coding_par.bitorder==ORDER_MSB?"M":"L",
 coding_par.byteorder==ORDER_MSB?"M":"L",
-coding_par.fieldorder==ORDER_MSB?"M":"L"
+coding_par.fieldorder==ORDER_MSB?"M":"L",
+coding_par.hexorder==ORDER_MSB?"M":"L"
 );
 printf("local bito:%s,field:%s\r\n",local_bitorder==ORDER_MSB?"M":"L",
 local_fieldorder==ORDER_MSB?"M":"L"
@@ -798,7 +799,7 @@ local_fieldorder==ORDER_MSB?"M":"L"
 //printf("new_size:%d new_bit_pos:%d\r\n",new_size,new_bit_pos);
   if(coding_par.hexorder==ORDER_MSB){
     st2=(unsigned char*)Malloc((len+7)/8*sizeof(unsigned char));
-    if(bit_pos==4){
+    if(bit_pos==4 && local_fieldorder==ORDER_LSB){
       st2[0]=s[0];
       for(size_t a=1;a<(len+7)/8;a++){
         unsigned char ch='\0';
@@ -809,7 +810,7 @@ local_fieldorder==ORDER_MSB?"M":"L"
     }
     else{
       for(size_t a=0;a<(len+7)/8;a++) st2[a]=(s[a]<<4)|(s[a]>>4);
-      if(len%8) st2[(len+7)/8]>>=4;
+      if(len%8) st2[((len+7)/8)-1]>>=4;
     }
     s=st2;
   }
@@ -1208,7 +1209,7 @@ void TTCN_Buffer::get_b(size_t len, unsigned char *s,
     }
   }
   if(coding_par.hexorder==ORDER_MSB){
-    if(bit_pos==4){
+    if(bit_pos==4 && local_fieldorder==ORDER_LSB){
       for(size_t a=1;a<(len+7)/8;a++){
         unsigned char ch='\0';
         ch|=s[a-1]>>4;
@@ -1218,7 +1219,7 @@ void TTCN_Buffer::get_b(size_t len, unsigned char *s,
     }
     else{
       for(size_t a=0;a<(len+7)/8;a++) s[a]=(s[a]<<4)|(s[a]>>4);
-      if(len%8) s[(len+7)/8]>>=4;
+      if(len%8) s[((len+7)/8)-1]>>=4;
     }
   }
 
@@ -1245,7 +1246,7 @@ void TTCN_Buffer::put_zero(size_t len, raw_order_t fieldorder)
       unsigned char mask1=BitMaskTable[bit_pos];
       unsigned char *prt=data_ptr+(buf_len==0?0:buf_len-1);
       if(fieldorder==ORDER_LSB) prt[0]&=mask1;
-      else prt[0]&=~mask1;
+      else prt[0]&=REVERSE_BITS(mask1);
       memset(prt+1, 0, (len-1+bit_pos)/8);
     }
     else {
@@ -1410,6 +1411,7 @@ unsigned char TTCN_Buffer::get_byte_align(size_t len,
                                           size_t idx)
 {
   if(idx>(bit_pos+len)/8) return '\0';
+  if((buf_pos+idx) >= buf_len) return '\0';
   const unsigned char *data_ptr = buf_ptr != NULL ? buf_ptr->data_ptr : NULL;
   if(idx==0){ // first byte
     if(fieldorder==req_align){
