@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2020 Ericsson Telecom AB
+ * Copyright (c) 2000-2021 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -347,7 +347,7 @@ void FLOAT::decode_text(Text_Buf& text_buf)
 }
 
 void FLOAT::encode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
-                   TTCN_EncDec::coding_t p_coding, ...) const
+                   int p_coding, ...) const
 {
   va_list pvar;
   va_start(pvar, p_coding);
@@ -400,7 +400,7 @@ void FLOAT::encode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
 }
 
 void FLOAT::decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
-                   TTCN_EncDec::coding_t p_coding, ...)
+                   int p_coding, ...)
 {
   va_list pvar;
   va_start(pvar, p_coding);
@@ -1135,11 +1135,16 @@ int FLOAT::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer& p_tok,
   char* value = 0;
   size_t value_len = 0;
   size_t dec_len = 0;
-  boolean use_default = p_td.json->default_value && 0 == p_tok.get_buffer_length();
-  if (use_default) {
+  boolean use_default = FALSE;
+  if (p_td.json->default_value.type == JD_STANDARD && 0 == p_tok.get_buffer_length()) {
+    *this = *static_cast<const FLOAT*>(p_td.json->default_value.val);
+    return dec_len;
+  }
+  if (p_td.json->default_value.type == JD_LEGACY && 0 == p_tok.get_buffer_length()) {
     // No JSON data in the buffer -> use default value
-    value = const_cast<char*>(p_td.json->default_value);
+    value = const_cast<char*>(p_td.json->default_value.str);
     value_len = strlen(value);
+    use_default = TRUE;
   } else {
     dec_len = p_tok.get_next_token(&token, &value, &value_len);
   }
@@ -1453,9 +1458,26 @@ boolean operator>(double double_value, const FLOAT& other_value)
 
 void FLOAT_template::clean_up()
 {
-  if (template_selection == VALUE_LIST ||
-      template_selection == COMPLEMENTED_LIST)
+  switch (template_selection) {
+  case VALUE_LIST:
+  case COMPLEMENTED_LIST:
+  case CONJUNCTION_MATCH:
     delete [] value_list.list_value;
+    break;
+  case IMPLICATION_MATCH:
+    delete implication_.precondition;
+    delete implication_.implied_template;
+    break;
+  case DYNAMIC_MATCH:
+    dyn_match->ref_count--;
+    if (dyn_match->ref_count == 0) {
+      delete dyn_match->ptr;
+      delete dyn_match;
+    }
+    break;
+  default:
+    break;
+  }
   template_selection = UNINITIALIZED_TEMPLATE;
 }
 
@@ -1471,6 +1493,7 @@ void FLOAT_template::copy_template(const FLOAT_template& other_value)
     break;
   case VALUE_LIST:
   case COMPLEMENTED_LIST:
+  case CONJUNCTION_MATCH:
     value_list.n_values = other_value.value_list.n_values;
     value_list.list_value = new FLOAT_template[value_list.n_values];
     for (unsigned int i = 0; i < value_list.n_values; i++)
@@ -1480,6 +1503,14 @@ void FLOAT_template::copy_template(const FLOAT_template& other_value)
   case VALUE_RANGE:
     value_range = other_value.value_range;
     break;
+  case IMPLICATION_MATCH:
+    implication_.precondition = new FLOAT_template(*other_value.implication_.precondition);
+    implication_.implied_template = new FLOAT_template(*other_value.implication_.implied_template);
+    break;
+  case DYNAMIC_MATCH:
+    dyn_match = other_value.dyn_match;
+    dyn_match->ref_count++;
+    break;
   default:
     TTCN_error("Copying an uninitialized/unsupported float template.");
   }
@@ -1531,6 +1562,21 @@ FLOAT_template::FLOAT_template(const FLOAT_template& other_value)
   copy_template(other_value);
 }
 
+FLOAT_template::FLOAT_template(FLOAT_template* p_precondition, FLOAT_template* p_implied_template)
+: Base_Template(IMPLICATION_MATCH)
+{
+  implication_.precondition = p_precondition;
+  implication_.implied_template = p_implied_template;
+}
+
+FLOAT_template::FLOAT_template(Dynamic_Match_Interface<FLOAT>* p_dyn_match)
+: Base_Template(DYNAMIC_MATCH)
+{
+  dyn_match = new dynmatch_struct<FLOAT>;
+  dyn_match->ptr = p_dyn_match;
+  dyn_match->ref_count = 1;
+}
+
 FLOAT_template::~FLOAT_template()
 {
   clean_up();
@@ -1621,6 +1667,17 @@ boolean FLOAT_template::match(double other_value, boolean /* legacy */) const
        (value_range.max_is_present && !value_range.max_is_exclusive && value_range.max_value >= other_value) ||
       // Max boundary is a number and max exclusive               and it is more than the value
        (value_range.max_is_present && value_range.max_is_exclusive && value_range.max_value > other_value));
+  case CONJUNCTION_MATCH:
+    for (unsigned int i = 0; i < value_list.n_values; i++) {
+      if (!value_list.list_value[i].match(other_value)) {
+        return FALSE;
+      }
+    }
+    return TRUE;
+  case IMPLICATION_MATCH:
+    return !implication_.precondition->match(other_value) || implication_.implied_template->match(other_value);
+  case DYNAMIC_MATCH:
+    return dyn_match->ptr->match(other_value);
   default:
     TTCN_error("Matching with an uninitialized/unsupported float template.");
   }
@@ -1641,6 +1698,7 @@ void FLOAT_template::set_type(template_sel template_type,
   switch (template_type) {
   case VALUE_LIST:
   case COMPLEMENTED_LIST:
+  case CONJUNCTION_MATCH:
     set_selection(template_type);
     value_list.n_values = list_length;
     value_list.list_value = new FLOAT_template[list_length];
@@ -1660,7 +1718,8 @@ void FLOAT_template::set_type(template_sel template_type,
 FLOAT_template& FLOAT_template::list_item(unsigned int list_index)
 {
   if (template_selection != VALUE_LIST &&
-      template_selection != COMPLEMENTED_LIST)
+      template_selection != COMPLEMENTED_LIST &&
+      template_selection != CONJUNCTION_MATCH)
     TTCN_error("Accessing a list element of a non-list float template.");
   if (list_index >= value_list.n_values)
     TTCN_error("Index overflow in a float value list template.");
@@ -1736,6 +1795,11 @@ void FLOAT_template::log() const
   case COMPLEMENTED_LIST:
     TTCN_Logger::log_event_str("complement");
     // no break
+  case CONJUNCTION_MATCH:
+    if (template_selection == CONJUNCTION_MATCH) {
+      TTCN_Logger::log_event_str("conjunct");
+    }
+    // no break
   case VALUE_LIST:
     TTCN_Logger::log_char('(');
     for (unsigned int i = 0; i < value_list.n_values; i++) {
@@ -1755,6 +1819,14 @@ void FLOAT_template::log() const
     else TTCN_Logger::log_event_str("infinity");
     TTCN_Logger::log_char(')');
     break;
+  case IMPLICATION_MATCH:
+    implication_.precondition->log();
+    TTCN_Logger::log_event_str(" implies ");
+    implication_.implied_template->log();
+    break;
+  case DYNAMIC_MATCH:
+    TTCN_Logger::log_event_str("@dynamic template");
+    break;
   default:
     log_generic();
     break;
@@ -1796,10 +1868,12 @@ void FLOAT_template::set_param(Module_Param& param) {
     *this = ANY_OR_OMIT;
     break;
   case Module_Param::MP_List_Template:
-  case Module_Param::MP_ComplementList_Template: {
+  case Module_Param::MP_ComplementList_Template:
+  case Module_Param::MP_ConjunctList_Template: {
     FLOAT_template temp;
     temp.set_type(mp->get_type() == Module_Param::MP_List_Template ?
-      VALUE_LIST : COMPLEMENTED_LIST, mp->get_size());
+      VALUE_LIST : (mp->get_type() == Module_Param::MP_ConjunctList_Template ?
+      CONJUNCTION_MATCH : COMPLEMENTED_LIST), mp->get_size());
     for (size_t i=0; i<mp->get_size(); i++) {
       temp.list_item(i).set_param(*mp->get_elem(i));
     }
@@ -1815,6 +1889,13 @@ void FLOAT_template::set_param(Module_Param& param) {
     set_min_exclusive(mp->get_is_min_exclusive());
     set_max_exclusive(mp->get_is_max_exclusive());
     break;
+  case Module_Param::MP_Implication_Template: {
+    FLOAT_template* precondition = new FLOAT_template;
+    precondition->set_param(*mp->get_elem(0));
+    FLOAT_template* implied_template = new FLOAT_template;
+    implied_template->set_param(*mp->get_elem(1));
+    *this = FLOAT_template(precondition, implied_template);
+  } break;
   case Module_Param::MP_Expression:
     switch (mp->get_expr_type()) {
     case Module_Param::EXPR_NEGATE: {
@@ -1881,10 +1962,14 @@ Module_Param* FLOAT_template::get_param(Module_Param_Name& param_name) const
     mp = new Module_Param_Float(single_value);
     break;
   case VALUE_LIST:
-  case COMPLEMENTED_LIST: {
+  case COMPLEMENTED_LIST:
+  case CONJUNCTION_MATCH: {
     if (template_selection == VALUE_LIST) {
       mp = new Module_Param_List_Template();
     }
+    else if (template_selection == CONJUNCTION_MATCH) {
+      mp = new Module_Param_ConjunctList_Template();
+    }
     else {
       mp = new Module_Param_ComplementList_Template();
     }
@@ -1897,6 +1982,11 @@ Module_Param* FLOAT_template::get_param(Module_Param_Name& param_name) const
       value_range.min_value, value_range.min_is_present,
       value_range.max_value, value_range.max_is_present, value_range.min_is_exclusive, value_range.max_is_exclusive);
     break;
+  case IMPLICATION_MATCH:
+    mp = new Module_Param_Implication_Template();
+    mp->add_elem(implication_.precondition->get_param(param_name));
+    mp->add_elem(implication_.implied_template->get_param(param_name));
+    break;
   default:
     TTCN_error("Referencing an uninitialized/unsupported float template.");
     break;
@@ -1987,6 +2077,8 @@ boolean FLOAT_template::match_omit(boolean legacy /* = FALSE */) const
   case OMIT_VALUE:
   case ANY_OR_OMIT:
     return TRUE;
+  case IMPLICATION_MATCH:
+    return !implication_.precondition->match_omit() || implication_.implied_template->match_omit();
   case VALUE_LIST:
   case COMPLEMENTED_LIST:
     if (legacy) {
