@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2020 Ericsson Telecom AB
+ * Copyright (c) 2000-2021 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -754,7 +754,7 @@ void INTEGER::decode_text(Text_Buf& text_buf)
 }
 
 void INTEGER::encode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
-                     TTCN_EncDec::coding_t p_coding, ...) const
+                     int p_coding, ...) const
 {
   va_list pvar;
   va_start(pvar, p_coding);
@@ -814,7 +814,7 @@ void INTEGER::encode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
 }
 
 void INTEGER::decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
-                     TTCN_EncDec::coding_t p_coding, ...)
+                     int p_coding, ...)
 {
   va_list pvar;
   va_start(pvar, p_coding);
@@ -1759,11 +1759,16 @@ int INTEGER::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer& p_to
   char* value = 0;
   size_t value_len = 0;
   size_t dec_len = 0;
-  boolean use_default = p_td.json->default_value && 0 == p_tok.get_buffer_length();
-  if (use_default) {
+  boolean use_default = FALSE;
+  if (p_td.json->default_value.type == JD_STANDARD && 0 == p_tok.get_buffer_length()) {
+    *this = *static_cast<const INTEGER*>(p_td.json->default_value.val);
+    return dec_len;
+  }
+  if (p_td.json->default_value.type == JD_LEGACY && 0 == p_tok.get_buffer_length()) {
     // No JSON data in the buffer -> use default value
-    value = const_cast<char*>(p_td.json->default_value);
+    value = const_cast<char*>(p_td.json->default_value.str);
     value_len = strlen(value);
+    use_default = TRUE;
   } else {
     dec_len = p_tok.get_next_token(&token, &value, &value_len);
   }
@@ -2072,6 +2077,7 @@ void INTEGER_template::clean_up()
       break;
     case VALUE_LIST:
     case COMPLEMENTED_LIST:
+    case CONJUNCTION_MATCH:
       delete [] value_list.list_value;
       break;
     case VALUE_RANGE:
@@ -2080,6 +2086,17 @@ void INTEGER_template::clean_up()
       if (value_range.max_is_present && unlikely(!value_range.max_value.native_flag))
         BN_free(value_range.max_value.val.openssl);
       break;
+    case IMPLICATION_MATCH:
+      delete implication_.precondition;
+      delete implication_.implied_template;
+      break;
+    case DYNAMIC_MATCH:
+      dyn_match->ref_count--;
+      if (dyn_match->ref_count == 0) {
+        delete dyn_match->ptr;
+        delete dyn_match;
+      }
+      break;
     default:
       break;
   }
@@ -2101,6 +2118,7 @@ void INTEGER_template::copy_template(const INTEGER_template& other_value)
     break;
   case VALUE_LIST:
   case COMPLEMENTED_LIST:
+  case CONJUNCTION_MATCH:
     value_list.n_values = other_value.value_list.n_values;
     value_list.list_value = new INTEGER_template[value_list.n_values];
     for (unsigned int i = 0; i < value_list.n_values; i++)
@@ -2131,6 +2149,14 @@ void INTEGER_template::copy_template(const INTEGER_template& other_value)
           BN_dup(other_value.value_range.max_value.val.openssl);
     }
     break;
+  case IMPLICATION_MATCH:
+    implication_.precondition = new INTEGER_template(*other_value.implication_.precondition);
+    implication_.implied_template = new INTEGER_template(*other_value.implication_.implied_template);
+    break;
+  case DYNAMIC_MATCH:
+    dyn_match = other_value.dyn_match;
+    dyn_match->ref_count++;
+    break;
   default:
     TTCN_error("Copying an uninitialized/unsupported integer template.");
   }
@@ -2191,6 +2217,21 @@ INTEGER_template::INTEGER_template(const INTEGER_template& other_value)
   copy_template(other_value);
 }
 
+INTEGER_template::INTEGER_template(INTEGER_template* p_precondition, INTEGER_template* p_implied_template)
+: Base_Template(IMPLICATION_MATCH)
+{
+  implication_.precondition = p_precondition;
+  implication_.implied_template = p_implied_template;
+}
+
+INTEGER_template::INTEGER_template(Dynamic_Match_Interface<INTEGER>* p_dyn_match)
+: Base_Template(DYNAMIC_MATCH)
+{
+  dyn_match = new dynmatch_struct<INTEGER>;
+  dyn_match->ptr = p_dyn_match;
+  dyn_match->ref_count = 1;
+}
+
 INTEGER_template::~INTEGER_template()
 {
   clean_up();
@@ -2305,6 +2346,17 @@ boolean INTEGER_template::match(int other_value, boolean /* legacy */) const
       }
     }
     return lower_boundary && upper_boundary; }
+  case CONJUNCTION_MATCH:
+    for (unsigned int i = 0; i < value_list.n_values; i++) {
+      if (!value_list.list_value[i].match(other_value)) {
+        return FALSE;
+      }
+    }
+    return TRUE;
+  case IMPLICATION_MATCH:
+    return !implication_.precondition->match(other_value) || implication_.implied_template->match(other_value);
+  case DYNAMIC_MATCH:
+    return dyn_match->ptr->match(other_value);
   default:
     TTCN_error("Matching with an uninitialized/unsupported integer "
       "template.");
@@ -2360,6 +2412,17 @@ boolean INTEGER_template::match(const INTEGER& other_value,
       }
       }
       return lower_boundary && upper_boundary; }
+    case CONJUNCTION_MATCH:
+      for (unsigned int i = 0; i < value_list.n_values; i++) {
+        if (!value_list.list_value[i].match(other_value)) {
+          return FALSE;
+        }
+      }
+      return TRUE;
+    case IMPLICATION_MATCH:
+      return !implication_.precondition->match(other_value) || implication_.implied_template->match(other_value);
+    case DYNAMIC_MATCH:
+      return dyn_match->ptr->match(other_value);
     default:
       TTCN_error("Matching with an uninitialized/unsupported integer "
         "template.");
@@ -2383,6 +2446,7 @@ void INTEGER_template::set_type(template_sel template_type,
   switch (template_type) {
   case VALUE_LIST:
   case COMPLEMENTED_LIST:
+  case CONJUNCTION_MATCH:
     set_selection(template_type);
     value_list.n_values = list_length;
     value_list.list_value = new INTEGER_template[list_length];
@@ -2402,7 +2466,8 @@ void INTEGER_template::set_type(template_sel template_type,
 INTEGER_template& INTEGER_template::list_item(unsigned int list_index)
 {
   if (template_selection != VALUE_LIST &&
-      template_selection != COMPLEMENTED_LIST)
+      template_selection != COMPLEMENTED_LIST &&
+      template_selection != CONJUNCTION_MATCH)
     TTCN_error("Accessing a list element of a non-list integer template.");
   if (list_index >= value_list.n_values)
     TTCN_error("Index overflow in an integer value list template.");
@@ -2519,6 +2584,11 @@ void INTEGER_template::log() const
   case COMPLEMENTED_LIST:
     TTCN_Logger::log_event_str("complement");
     // no break
+  case CONJUNCTION_MATCH:
+    if (template_selection == CONJUNCTION_MATCH) {
+      TTCN_Logger::log_event_str("conjunct");
+    }
+    // no break
   case VALUE_LIST:
     TTCN_Logger::log_char('(');
     for (unsigned int i = 0; i < value_list.n_values; i++) {
@@ -2554,6 +2624,14 @@ void INTEGER_template::log() const
     }
     TTCN_Logger::log_char(')');
     break;
+  case IMPLICATION_MATCH:
+    implication_.precondition->log();
+    TTCN_Logger::log_event_str(" implies ");
+    implication_.implied_template->log();
+    break;
+  case DYNAMIC_MATCH:
+    TTCN_Logger::log_event_str("@dynamic template");
+    break;
   default:
     log_generic();
     break;
@@ -2595,10 +2673,12 @@ void INTEGER_template::set_param(Module_Param& param) {
     *this = ANY_OR_OMIT;
     break;
   case Module_Param::MP_List_Template:
-  case Module_Param::MP_ComplementList_Template: {
+  case Module_Param::MP_ComplementList_Template:
+  case Module_Param::MP_ConjunctList_Template: {
     INTEGER_template temp;
     temp.set_type(mp->get_type() == Module_Param::MP_List_Template ?
-      VALUE_LIST : COMPLEMENTED_LIST, mp->get_size());
+      VALUE_LIST : (mp->get_type() == Module_Param::MP_ConjunctList_Template ?
+      CONJUNCTION_MATCH : COMPLEMENTED_LIST), mp->get_size());
     for (size_t i=0; i<mp->get_size(); i++) {
       temp.list_item(i).set_param(*mp->get_elem(i));
     }
@@ -2624,6 +2704,13 @@ void INTEGER_template::set_param(Module_Param& param) {
     }
     set_max_exclusive(mp->get_is_max_exclusive());
   } break;
+  case Module_Param::MP_Implication_Template: {
+    INTEGER_template* precondition = new INTEGER_template;
+    precondition->set_param(*mp->get_elem(0));
+    INTEGER_template* implied_template = new INTEGER_template;
+    implied_template->set_param(*mp->get_elem(1));
+    *this = INTEGER_template(precondition, implied_template);
+  } break;
   case Module_Param::MP_Expression:
     switch (mp->get_expr_type()) {
     case Module_Param::EXPR_NEGATE: {
@@ -2695,10 +2782,14 @@ Module_Param* INTEGER_template::get_param(Module_Param_Name& param_name) const
     }
     break;
   case VALUE_LIST:
-  case COMPLEMENTED_LIST: {
+  case COMPLEMENTED_LIST:
+  case CONJUNCTION_MATCH: {
     if (template_selection == VALUE_LIST) {
       mp = new Module_Param_List_Template();
     }
+    else if (template_selection == CONJUNCTION_MATCH) {
+      mp = new Module_Param_ConjunctList_Template();
+    }
     else {
       mp = new Module_Param_ComplementList_Template();
     }
@@ -2727,6 +2818,11 @@ Module_Param* INTEGER_template::get_param(Module_Param_Name& param_name) const
     }
     mp = new Module_Param_IntRange(lower_bound, upper_bound, value_range.min_is_exclusive, value_range.max_is_exclusive);
     break; }
+  case IMPLICATION_MATCH:
+    mp = new Module_Param_Implication_Template();
+    mp->add_elem(implication_.precondition->get_param(param_name));
+    mp->add_elem(implication_.implied_template->get_param(param_name));
+    break;
   default:
     TTCN_error("Referencing an uninitialized/unsupported integer template.");
     break;
@@ -2835,6 +2931,8 @@ boolean INTEGER_template::match_omit(boolean legacy /* = FALSE */) const
   case OMIT_VALUE:
   case ANY_OR_OMIT:
     return TRUE;
+  case IMPLICATION_MATCH:
+    return !implication_.precondition->match_omit() || implication_.implied_template->match_omit();
   case VALUE_LIST:
   case COMPLEMENTED_LIST:
     if (legacy) {
