@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2020 Ericsson Telecom AB
+ * Copyright (c) 2000-2021 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -278,7 +278,7 @@ void OBJID::decode_text(Text_Buf& text_buf)
 }
 
 void OBJID::encode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
-                   TTCN_EncDec::coding_t p_coding, ...) const
+                   int p_coding, ...) const
 {
   va_list pvar;
   va_start(pvar, p_coding);
@@ -324,7 +324,7 @@ void OBJID::encode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
 }
 
 void OBJID::decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf,
-                   TTCN_EncDec::coding_t p_coding, ...)
+                   int p_coding, ...)
 {
   va_list pvar;
   va_start(pvar, p_coding);
@@ -638,11 +638,16 @@ int OBJID::JSON_decode(const TTCN_Typedescriptor_t& p_td, JSON_Tokenizer& p_tok,
   size_t value_len = 0;
   boolean error = FALSE;
   size_t dec_len = 0;
-  boolean use_default = p_td.json->default_value && 0 == p_tok.get_buffer_length();
-  if (use_default) {
+  boolean use_default = FALSE;
+  if (p_td.json->default_value.type == JD_STANDARD && 0 == p_tok.get_buffer_length()) {
+    *this = *static_cast<const OBJID*>(p_td.json->default_value.val);
+    return dec_len;
+  }
+  if (p_td.json->default_value.type == JD_LEGACY && 0 == p_tok.get_buffer_length()) {
     // No JSON data in the buffer -> use default value
-    value = const_cast<char*>(p_td.json->default_value);
+    value = const_cast<char*>(p_td.json->default_value.str);
     value_len = strlen(value);
+    use_default = TRUE;
   } else {
     dec_len = p_tok.get_next_token(&token, &value, &value_len);
   }
@@ -756,8 +761,26 @@ int OBJID::OER_decode(const TTCN_Typedescriptor_t& p_td, TTCN_Buffer& p_buf, OER
 
 void OBJID_template::clean_up()
 {
-  if (template_selection == VALUE_LIST ||
-    template_selection == COMPLEMENTED_LIST) delete [] value_list.list_value;
+  switch (template_selection) {
+  case VALUE_LIST:
+  case COMPLEMENTED_LIST:
+  case CONJUNCTION_MATCH:
+    delete [] value_list.list_value;
+    break;
+  case IMPLICATION_MATCH:
+    delete implication_.precondition;
+    delete implication_.implied_template;
+    break;
+  case DYNAMIC_MATCH:
+    dyn_match->ref_count--;
+    if (dyn_match->ref_count == 0) {
+      delete dyn_match->ptr;
+      delete dyn_match;
+    }
+    break;
+  default:
+    break;
+  }
   template_selection = UNINITIALIZED_TEMPLATE;
 }
 
@@ -773,12 +796,21 @@ void OBJID_template::copy_template(const OBJID_template& other_value)
     break;
   case VALUE_LIST:
   case COMPLEMENTED_LIST:
+  case CONJUNCTION_MATCH:
     value_list.n_values = other_value.value_list.n_values;
     value_list.list_value = new OBJID_template[value_list.n_values];
     for (unsigned int i = 0; i < value_list.n_values; i++)
       value_list.list_value[i].copy_template(
 	other_value.value_list.list_value[i]);
     break;
+  case IMPLICATION_MATCH:
+    implication_.precondition = new OBJID_template(*other_value.implication_.precondition);
+    implication_.implied_template = new OBJID_template(*other_value.implication_.implied_template);
+    break;
+  case DYNAMIC_MATCH:
+    dyn_match = other_value.dyn_match;
+    dyn_match->ref_count++;
+    break;
   default:
     TTCN_error("Copying an uninitialized/unsupported objid template.");
   }
@@ -823,6 +855,21 @@ OBJID_template::OBJID_template(const OBJID_template& other_value)
   copy_template(other_value);
 }
 
+OBJID_template::OBJID_template(OBJID_template* p_precondition, OBJID_template* p_implied_template)
+: Base_Template(IMPLICATION_MATCH)
+{
+  implication_.precondition = p_precondition;
+  implication_.implied_template = p_implied_template;
+}
+
+OBJID_template::OBJID_template(Dynamic_Match_Interface<OBJID>* p_dyn_match)
+: Base_Template(DYNAMIC_MATCH)
+{
+  dyn_match = new dynmatch_struct<OBJID>;
+  dyn_match->ptr = p_dyn_match;
+  dyn_match->ref_count = 1;
+}
+
 OBJID_template::~OBJID_template()
 {
   clean_up();
@@ -889,6 +936,17 @@ boolean OBJID_template::match(const OBJID& other_value, boolean /* legacy */) co
       if (value_list.list_value[i].match(other_value))
         return template_selection == VALUE_LIST;
     return template_selection == COMPLEMENTED_LIST;
+  case CONJUNCTION_MATCH:
+    for (unsigned int i = 0; i < value_list.n_values; i++) {
+      if (!value_list.list_value[i].match(other_value)) {
+        return FALSE;
+      }
+    }
+    return TRUE;
+  case IMPLICATION_MATCH:
+    return !implication_.precondition->match(other_value) || implication_.implied_template->match(other_value);
+  case DYNAMIC_MATCH:
+    return dyn_match->ptr->match(other_value);
   default:
     TTCN_error("Matching with an uninitialized/unsupported objid template.");
   }
@@ -932,6 +990,15 @@ int OBJID_template::size_of() const
   case COMPLEMENTED_LIST:
     TTCN_error("Performing sizeof() operation on an objid template "
                "containing complemented list.");
+  case CONJUNCTION_MATCH:
+    TTCN_error("Performing sizeof() operation on a objid template "
+               "containing a conjunction list match.");
+  case IMPLICATION_MATCH:
+    TTCN_error("Performing sizeof() operation on a objid template "
+               "containing an implication match.");
+  case DYNAMIC_MATCH:
+    TTCN_error("Performing sizeof() operation on a objid template "
+               "containing a dynamic match.");
   default:
     TTCN_error("Performing sizeof() operation on an "
                "uninitialized/unsupported objid template.");
@@ -942,7 +1009,8 @@ int OBJID_template::size_of() const
 void OBJID_template::set_type(template_sel template_type,
   unsigned int list_length)
 {
-  if (template_type != VALUE_LIST && template_type != COMPLEMENTED_LIST)
+  if (template_type != VALUE_LIST && template_type != COMPLEMENTED_LIST &&
+      template_type != CONJUNCTION_MATCH)
       TTCN_error("Setting an invalid list type for an objid template.");
   clean_up();
   set_selection(template_type);
@@ -953,7 +1021,8 @@ void OBJID_template::set_type(template_sel template_type,
 OBJID_template& OBJID_template::list_item(unsigned int list_index)
 {
   if (template_selection != VALUE_LIST &&
-    template_selection != COMPLEMENTED_LIST)
+      template_selection != COMPLEMENTED_LIST &&
+      template_selection != CONJUNCTION_MATCH)
     TTCN_error("Accessing a list element of a non-list objid template.");
   if (list_index >= value_list.n_values)
     TTCN_error("Index overflow in an objid value list template.");
@@ -969,6 +1038,11 @@ void OBJID_template::log() const
   case COMPLEMENTED_LIST:
     TTCN_Logger::log_event_str("complement");
     // no break
+  case CONJUNCTION_MATCH:
+    if (template_selection == CONJUNCTION_MATCH) {
+      TTCN_Logger::log_event_str("conjunct");
+    }
+    // no break
   case VALUE_LIST:
     TTCN_Logger::log_char('(');
     for(unsigned int i = 0; i < value_list.n_values; i++) {
@@ -977,6 +1051,14 @@ void OBJID_template::log() const
     }
     TTCN_Logger::log_char(')');
     break;
+  case IMPLICATION_MATCH:
+    implication_.precondition->log();
+    TTCN_Logger::log_event_str(" implies ");
+    implication_.implied_template->log();
+    break;
+  case DYNAMIC_MATCH:
+    TTCN_Logger::log_event_str("@dynamic template");
+    break;
   default:
     log_generic();
     break;
@@ -1018,10 +1100,12 @@ void OBJID_template::set_param(Module_Param& param) {
     *this = ANY_OR_OMIT;
     break;
   case Module_Param::MP_List_Template:
-  case Module_Param::MP_ComplementList_Template: {
+  case Module_Param::MP_ComplementList_Template:
+  case Module_Param::MP_ConjunctList_Template: {
     OBJID_template temp;
     temp.set_type(mp->get_type() == Module_Param::MP_List_Template ?
-      VALUE_LIST : COMPLEMENTED_LIST, mp->get_size());
+      VALUE_LIST : (mp->get_type() == Module_Param::MP_ConjunctList_Template ?
+      CONJUNCTION_MATCH : COMPLEMENTED_LIST), mp->get_size());
     for (size_t i=0; i<mp->get_size(); i++) {
       temp.list_item(i).set_param(*mp->get_elem(i));
     }
@@ -1031,6 +1115,13 @@ void OBJID_template::set_param(Module_Param& param) {
     if (sizeof(OBJID::objid_element)!=sizeof(int)) TTCN_error("Internal error: OBJID_template::set_param()"); 
     *this = OBJID(mp->get_string_size(), (OBJID::objid_element*)mp->get_string_data());
     break;
+  case Module_Param::MP_Implication_Template: {
+    OBJID_template* precondition = new OBJID_template;
+    precondition->set_param(*mp->get_elem(0));
+    OBJID_template* implied_template = new OBJID_template;
+    implied_template->set_param(*mp->get_elem(1));
+    *this = OBJID_template(precondition, implied_template);
+  } break;
   //case Module_Param::MP_Objid_Template:
   // TODO
   //break;
@@ -1061,10 +1152,14 @@ Module_Param* OBJID_template::get_param(Module_Param_Name& param_name) const
     mp = single_value.get_param(param_name);
     break;
   case VALUE_LIST:
-  case COMPLEMENTED_LIST: {
+  case COMPLEMENTED_LIST:
+  case CONJUNCTION_MATCH: {
     if (template_selection == VALUE_LIST) {
       mp = new Module_Param_List_Template();
     }
+    else if (template_selection == CONJUNCTION_MATCH) {
+      mp = new Module_Param_ConjunctList_Template();
+    }
     else {
       mp = new Module_Param_ComplementList_Template();
     }
@@ -1072,6 +1167,11 @@ Module_Param* OBJID_template::get_param(Module_Param_Name& param_name) const
       mp->add_elem(value_list.list_value[i].get_param(param_name));
     }
     break; }
+  case IMPLICATION_MATCH:
+    mp = new Module_Param_Implication_Template();
+    mp->add_elem(implication_.precondition->get_param(param_name));
+    mp->add_elem(implication_.implied_template->get_param(param_name));
+    break;
   default:
     TTCN_error("Referencing an uninitialized/unsupported objid template.");
     break;
@@ -1144,6 +1244,8 @@ boolean OBJID_template::match_omit(boolean legacy /* = FALSE */) const
   case OMIT_VALUE:
   case ANY_OR_OMIT:
     return TRUE;
+  case IMPLICATION_MATCH:
+    return !implication_.precondition->match_omit() || implication_.implied_template->match_omit();
   case VALUE_LIST:
   case COMPLEMENTED_LIST:
     if (legacy) {
