@@ -142,6 +142,11 @@ OCTETSTRING& OCTETSTRING::operator=(const OCTETSTRING_ELEMENT& other_value)
   return *this;
 }
 
+OCTETSTRING& OCTETSTRING::operator=(const INTEGER& other_value)
+{
+  return this->operator=(int2oct(other_value, val_ptr->n_octets));
+}
+
 boolean OCTETSTRING::operator==(const OCTETSTRING& other_value) const
 {
   must_bound("Unbound left operand of octetstring comparison.");
@@ -517,6 +522,16 @@ void OCTETSTRING::log() const
   } else TTCN_Logger::log_event_unbound();
 }
 
+INTEGER OCTETSTRING::convert_to_Integer(const TTCN_Typedescriptor_t& p_td)
+{
+  TTCN_EncDec_ErrorContext ec("While converting to integer type '%s': ", p_td.name);
+  TTCN_Buffer ttcn_buf(*this);
+  raw_order_t order = p_td.raw->top_bit_order == TOP_BIT_LEFT ? ORDER_LSB : ORDER_MSB;
+  INTEGER integer;
+  integer.RAW_decode(p_td, ttcn_buf, ttcn_buf.get_len() * 8, order);
+  return integer;
+}
+
 void OCTETSTRING::set_param(Module_Param& param) {
   param.basic_check(Module_Param::BC_VALUE|Module_Param::BC_LIST, "octetstring value");
   Module_Param_Ptr mp = &param;
