@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2020 Ericsson Telecom AB
+ * Copyright (c) 2000-2021 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -632,6 +632,12 @@ void Module_Param_Compound::add_list_with_implicit_ids(Vector<Module_Param*>* mp
   }
 }
 
+void Module_Param_Implication_Template::log_value() const {
+  values[0]->log();
+  TTCN_Logger::log_event_str(" implies ");
+  values[1]->log();
+}
+
 char* Module_Param::get_param_context() const {
   char* result = NULL;
   if (parent != NULL) {
