@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (c) 2000-2020 Ericsson Telecom AB
+ * Copyright (c) 2000-2021 Ericsson Telecom AB
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v2.0
  * which accompanies this distribution, and is available at
@@ -23,7 +23,7 @@
 // Author:                Vilmos Varga
 // mail:                  ethvva@eth.ericsson.se
 //
-// Copyright (c) 2000-2020 Ericsson Telecom AB
+// Copyright (c) 2000-2021 Ericsson Telecom AB
 //
 //----------------------------------------------------------------------------
 
@@ -273,7 +273,7 @@ int main(int argc, char *argv[])
       "(CLI)"
 #endif
       " for the TTCN-3 Test Executor\n"
-      "Product number: " PRODUCT_NUMBER "\n"
+      "Version: " VERSION_STRING "\n"
       "Build date: " __DATE__ " " __TIME__ "\n"
       "Compiled with: " C_COMPILER_VERSION "\n", stderr);
     fputs("Using ", stderr);
